==> haskell-tasty-0.11.0.2-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-tasty/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty
version: 0.11.0.2
id: tasty-0.11.0.2-59915c063df51d2eaf213c92cd2c46a4
key: tasty_1j2fMTQGeOpBDfE72KtF9X
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: http://documentup.com/feuerbach/tasty
synopsis: Modern and extensible testing framework
description:
    Tasty is a modern testing framework for Haskell.
    It lets you combine your unit tests, golden
    tests, QuickCheck/SmallCheck properties, and any
    other types of tests into a single test suite.
    See <http://documentup.com/feuerbach/tasty>.
category: Testing
author: Roman Cheplyaka <roma@ro-che.info>
exposed: True
exposed-modules:
    Test.Tasty Test.Tasty.Options Test.Tasty.Providers
    Test.Tasty.Runners Test.Tasty.Ingredients
    Test.Tasty.Ingredients.Basic
hidden-modules: Test.Tasty.Parallel Test.Tasty.Core
                Test.Tasty.Options.Core Test.Tasty.Options.Env Test.Tasty.Patterns
                Test.Tasty.Run Test.Tasty.Runners.Reducers Test.Tasty.Runners.Utils
                Test.Tasty.CmdLine Test.Tasty.Ingredients.ConsoleReporter
                Test.Tasty.Ingredients.ListTests
                Test.Tasty.Ingredients.IncludingOptions
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/tasty-0.11.0.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/tasty-0.11.0.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/tasty-0.11.0.2
hs-libraries: HStasty-0.11.0.2-1j2fMTQGeOpBDfE72KtF9X
depends:
    ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
    async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    clock-0.7.1.1-48205698dc759abc70fe01a1aa47cc9f
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    optparse-applicative-0.12.1.0-efdb53d7ee5eb339e181252750b5ba21
    regex-tdfa-1.2.1-506e9a407febb132e40b4c629d403ead
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    unbounded-delays-0.1.0.9-d8d3d98a397b27cddff9df391347a222
haddock-interfaces: /usr/share/doc/haskell-tasty/html/tasty.haddock
haddock-html: /usr/share/doc/haskell-tasty/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-0.11.0.3-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-tasty/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty
version: 0.11.0.3
id: tasty-0.11.0.3-0d04c7a0c25a1cdf39b68aca17d97b9d
key: tasty_3RKL7XZrwEh5DJ37KB7WJC
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: http://documentup.com/feuerbach/tasty
synopsis: Modern and extensible testing framework
description:
    Tasty is a modern testing framework for Haskell.
    It lets you combine your unit tests, golden
    tests, QuickCheck/SmallCheck properties, and any
    other types of tests into a single test suite.
    See <http://documentup.com/feuerbach/tasty>.
category: Testing
author: Roman Cheplyaka <roma@ro-che.info>
exposed: True
exposed-modules:
    Test.Tasty Test.Tasty.Options Test.Tasty.Providers
    Test.Tasty.Runners Test.Tasty.Ingredients
    Test.Tasty.Ingredients.Basic
hidden-modules: Test.Tasty.Parallel Test.Tasty.Core
                Test.Tasty.Options.Core Test.Tasty.Options.Env Test.Tasty.Patterns
                Test.Tasty.Run Test.Tasty.Runners.Reducers Test.Tasty.Runners.Utils
                Test.Tasty.CmdLine Test.Tasty.Ingredients.ConsoleReporter
                Test.Tasty.Ingredients.ListTests
                Test.Tasty.Ingredients.IncludingOptions
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/tasty-0.11.0.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/tasty-0.11.0.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/tasty-0.11.0.3
hs-libraries: HStasty-0.11.0.3-3RKL7XZrwEh5DJ37KB7WJC
depends:
    ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
    async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    clock-0.7.2-d9df232649dd50ab099f24881122ce3e
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    optparse-applicative-0.12.1.0-efdb53d7ee5eb339e181252750b5ba21
    regex-tdfa-1.2.2-5c2f2dacf3d81105b689ea15cddbfda5
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
    unbounded-delays-0.1.0.9-d8d3d98a397b27cddff9df391347a222
haddock-interfaces: /usr/share/doc/haskell-tasty/html/tasty.haddock
haddock-html: /usr/share/doc/haskell-tasty/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
